@@ -36,6 +36,9 @@
 int webauth_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data, int data_size, gchar **response)
 {
     gchar *begin, *end;
+    MSA_UNUSED(inner_req)
+    MSA_UNUSED(cp)
+    MSA_UNUSED(data_size)
     if (data == NULL) {
         *response = g_strdup(MSG_AUTH_ERROR);
         return 1;
@@ -43,7 +46,7 @@ int webauth_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* dat
 
     msa_debug("Received from webauth : %s", data);
 
-    if (strstr(data, "access_denied")) {
+    if (strstr(data, "access_denied") || g_strcmp0(data, "closed") == 0) {
         *response = g_strdup(MSG_AUTH_CANCEL);
         return 1;
     }
@@ -84,10 +87,11 @@ int json_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data,
     gchar* tmp_str = NULL;
     char *key; struct json_object *val; struct lh_entry *entry;
     char *ekey; struct json_object *eval; struct lh_entry *eentry;
+    MSA_UNUSED(inner_req)
+    MSA_UNUSED(cp)
+    MSA_UNUSED(data_size)
 
     if(data != NULL) {
-        g_debug("In json format:");
-        g_debug(data);
         buf = json_tokener_parse(data);
         if(buf != NULL) {
             if (is_error(buf)){
@@ -124,8 +128,6 @@ int json_parser(xmlDocPtr inner_req, const struct ProfileData *cp, gchar* data,
             g_free(tmp_str);
             *response = resp_str;
             json_object_put(buf);
-        g_debug("In xml format:");
-        g_debug(*response);
             return 0;
          } 
 
