@@ -57,9 +57,7 @@ struct ProfileData *profile_create(gchar *name)
     else
         ret->id = g_strdup_printf("%s", name);
 
-    ret->remixmid = NULL;
     ret->remixsid = NULL;
-    ret->secret = NULL;
     ret->next = NULL;
 
     return ret;
@@ -72,16 +70,10 @@ struct ProfileData *profile_create(gchar *name)
  */
 void profile_remove(struct ProfileData *data)
 {
-    if (data->id != NULL)
-	g_free(data->id);
-    if (data->remixmid != NULL)
-	g_free(data->remixmid);
-    if (data->remixsid != NULL)
-	g_free(data->remixsid);
-    if (data->secret != NULL)
-	g_free(data->secret);
-
-
+    if (data == NULL)
+        return;
+    g_free(data->id);
+    g_free(data->remixsid);
     free(data);
 }
 
@@ -116,42 +108,15 @@ int profile_update(struct ProfileData *data, xmlDocPtr settings)
     xmlNodePtr node = NULL;
     msa_debug("profile_update START");
 
-    if (data != NULL){
+    if (data == NULL)
+        return 1;
 
-        node = xpath_get_node("//*/Params/string[@name='mid']", settings);
-        if (node == NULL)
-            return 1;
-        if (data->remixmid != NULL)
-        {
-            g_free(data->remixmid);
-            data->remixmid = NULL;
-        }
-        data->remixmid = (gchar *)xmlNodeGetContent(node);
-
-        node = xpath_get_node("//*/Params/string[@name='sid']", settings);
-        if (node == NULL)
-            return 1;
-        if (data->remixsid != NULL)
-        {
-            g_free(data->remixsid);
-            data->remixsid = NULL;
-        }
-        data->remixsid = (gchar *)xmlNodeGetContent(node);
-
-        node = xpath_get_node("//*/Params/string[@name='secret']", settings);
-        if (node == NULL)
-            return 1;
-        if (data->secret != NULL)
-        {
-            g_free(data->secret);
-            data->secret = NULL;
-        }
-        data->secret = (gchar *)xmlNodeGetContent(node);
-
-        return 0;
-    }
-
-    return 1;
+    node = xpath_get_node("//*/Params/string[@name='sid']", settings);
+    if (node == NULL)
+        return 1;
+    g_free(data->remixsid);
+    data->remixsid = (gchar *)xmlNodeGetContent(node);
+    return 0;
 }
 
 /**
@@ -164,7 +129,7 @@ int profile_check(const struct ProfileData *data)
 {
     if (data == NULL)
         return 1;
-    if (data->id == NULL || data->remixmid == NULL || data->remixsid == NULL || data->secret == NULL)
+    if (data->id == NULL || data->remixsid == NULL)
         return 1;
     else 
         return 0;
@@ -177,26 +142,18 @@ int profile_check(const struct ProfileData *data)
  */
 gchar** profile_get_params(const struct ProfileData *data)
 {
-    gchar *tmp[7];
+    gchar *tmp[3];
     gchar **params;
     if(data != NULL){
-        tmp[0] = g_strdup("MID");
-        tmp[1] = g_strdup_printf("\"%s\"", data->remixmid);
-        tmp[2] = g_strdup("SID");
-        tmp[3] = g_strdup_printf("\"%s\"", data->remixsid);
-        tmp[4] = g_strdup("SECRET");
-        tmp[5] = g_strdup_printf("\"%s\"", data->secret);
-        tmp[6] = NULL;
+        tmp[0] = g_strdup("SID");
+        tmp[1] = g_strdup_printf("\"%s\"", data->remixsid);
+        tmp[2] = NULL;
     } else
         return NULL;
 
     params = g_strdupv(tmp);
     g_free((gpointer*)tmp[0]);
     g_free((gpointer*)tmp[1]);
-    g_free((gpointer*)tmp[2]);
-    g_free((gpointer*)tmp[3]);
-    g_free((gpointer*)tmp[4]);
-    g_free((gpointer*)tmp[5]);
 
     return params;
 }
