@@ -38,9 +38,7 @@
  */
 struct ProfileData {
     gchar *id;
-    gchar *remixmid;
     gchar *remixsid;
-    gchar *secret;
     struct ProfileData *next;
 };
 
